# Phase 4. Realize, Deploy, and Run: Transformations and Monitoring
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run#overview)
  * [Step 1. Run Implemented Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run#step-1.-run-implemented-transformation)
  * [Step 2. Monitor the Impact of Transformations](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run#step-2.-monitor-the-impact-of-transformations)
  * [Step 3. Report and Communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run#step-3.-report-and-communicate)
  * [Resources](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run#resources)


Run transformations, measure, and monitor progress using SAP LeanIX. Achieve transparency, communicate developments, and reflect on architecture changes for a successful transformation journey.
